"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListApplicationDependencies = void 0;
const ListApplicationDependenciesCommand_1 = require("../commands/ListApplicationDependenciesCommand");
const ServerlessApplicationRepository_1 = require("../ServerlessApplicationRepository");
const ServerlessApplicationRepositoryClient_1 = require("../ServerlessApplicationRepositoryClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListApplicationDependenciesCommand_1.ListApplicationDependenciesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listApplicationDependencies(input, ...args);
};
async function* paginateListApplicationDependencies(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxItems"] = config.pageSize;
        if (config.client instanceof ServerlessApplicationRepository_1.ServerlessApplicationRepository) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof ServerlessApplicationRepositoryClient_1.ServerlessApplicationRepositoryClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ServerlessApplicationRepository | ServerlessApplicationRepositoryClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListApplicationDependencies = paginateListApplicationDependencies;
