import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { ServerlessApplicationRepositoryServiceException as __BaseException } from "./ServerlessApplicationRepositoryServiceException";

export interface ApplicationDependencySummary {
    
    ApplicationId: string | undefined;
    
    SemanticVersion: string | undefined;
}
export declare namespace ApplicationDependencySummary {
    
    const filterSensitiveLog: (obj: ApplicationDependencySummary) => any;
}

export interface ApplicationPolicyStatement {
    
    Actions: string[] | undefined;
    
    PrincipalOrgIDs?: string[];
    
    Principals: string[] | undefined;
    
    StatementId?: string;
}
export declare namespace ApplicationPolicyStatement {
    
    const filterSensitiveLog: (obj: ApplicationPolicyStatement) => any;
}

export interface ApplicationSummary {
    
    ApplicationId: string | undefined;
    
    Author: string | undefined;
    
    CreationTime?: string;
    
    Description: string | undefined;
    
    HomePageUrl?: string;
    
    Labels?: string[];
    
    Name: string | undefined;
    
    SpdxLicenseId?: string;
}
export declare namespace ApplicationSummary {
    
    const filterSensitiveLog: (obj: ApplicationSummary) => any;
}
export declare enum Capability {
    CAPABILITY_AUTO_EXPAND = "CAPABILITY_AUTO_EXPAND",
    CAPABILITY_IAM = "CAPABILITY_IAM",
    CAPABILITY_NAMED_IAM = "CAPABILITY_NAMED_IAM",
    CAPABILITY_RESOURCE_POLICY = "CAPABILITY_RESOURCE_POLICY"
}

export interface ParameterDefinition {
    
    AllowedPattern?: string;
    
    AllowedValues?: string[];
    
    ConstraintDescription?: string;
    
    DefaultValue?: string;
    
    Description?: string;
    
    MaxLength?: number;
    
    MaxValue?: number;
    
    MinLength?: number;
    
    MinValue?: number;
    
    Name: string | undefined;
    
    NoEcho?: boolean;
    
    ReferencedByResources: string[] | undefined;
    
    Type?: string;
}
export declare namespace ParameterDefinition {
    
    const filterSensitiveLog: (obj: ParameterDefinition) => any;
}

export interface ParameterValue {
    
    Name: string | undefined;
    
    Value: string | undefined;
}
export declare namespace ParameterValue {
    
    const filterSensitiveLog: (obj: ParameterValue) => any;
}

export interface RollbackTrigger {
    
    Arn: string | undefined;
    
    Type: string | undefined;
}
export declare namespace RollbackTrigger {
    
    const filterSensitiveLog: (obj: RollbackTrigger) => any;
}

export interface Tag {
    
    Key: string | undefined;
    
    Value: string | undefined;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}

export interface VersionSummary {
    
    ApplicationId: string | undefined;
    
    CreationTime: string | undefined;
    
    SemanticVersion: string | undefined;
    
    SourceCodeUrl?: string;
}
export declare namespace VersionSummary {
    
    const filterSensitiveLog: (obj: VersionSummary) => any;
}

export declare class BadRequestException extends __BaseException {
    readonly name: "BadRequestException";
    readonly $fault: "client";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<BadRequestException, __BaseException>);
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface CreateApplicationRequest {
    
    Author: string | undefined;
    
    Description: string | undefined;
    
    HomePageUrl?: string;
    
    Labels?: string[];
    
    LicenseBody?: string;
    
    LicenseUrl?: string;
    
    Name: string | undefined;
    
    ReadmeBody?: string;
    
    ReadmeUrl?: string;
    
    SemanticVersion?: string;
    
    SourceCodeArchiveUrl?: string;
    
    SourceCodeUrl?: string;
    
    SpdxLicenseId?: string;
    
    TemplateBody?: string;
    
    TemplateUrl?: string;
}
export declare namespace CreateApplicationRequest {
    
    const filterSensitiveLog: (obj: CreateApplicationRequest) => any;
}

export interface Version {
    
    ApplicationId: string | undefined;
    
    CreationTime: string | undefined;
    
    ParameterDefinitions: ParameterDefinition[] | undefined;
    
    RequiredCapabilities: (Capability | string)[] | undefined;
    
    ResourcesSupported: boolean | undefined;
    
    SemanticVersion: string | undefined;
    
    SourceCodeArchiveUrl?: string;
    
    SourceCodeUrl?: string;
    
    TemplateUrl: string | undefined;
}
export declare namespace Version {
    
    const filterSensitiveLog: (obj: Version) => any;
}
export interface CreateApplicationResponse {
    
    ApplicationId?: string;
    
    Author?: string;
    
    CreationTime?: string;
    
    Description?: string;
    
    HomePageUrl?: string;
    
    IsVerifiedAuthor?: boolean;
    
    Labels?: string[];
    
    LicenseUrl?: string;
    
    Name?: string;
    
    ReadmeUrl?: string;
    
    SpdxLicenseId?: string;
    
    VerifiedAuthorUrl?: string;
    
    Version?: Version;
}
export declare namespace CreateApplicationResponse {
    
    const filterSensitiveLog: (obj: CreateApplicationResponse) => any;
}

export declare class ForbiddenException extends __BaseException {
    readonly name: "ForbiddenException";
    readonly $fault: "client";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ForbiddenException, __BaseException>);
}

export declare class InternalServerErrorException extends __BaseException {
    readonly name: "InternalServerErrorException";
    readonly $fault: "server";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InternalServerErrorException, __BaseException>);
}

export declare class TooManyRequestsException extends __BaseException {
    readonly name: "TooManyRequestsException";
    readonly $fault: "client";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<TooManyRequestsException, __BaseException>);
}
export interface CreateApplicationVersionRequest {
    
    ApplicationId: string | undefined;
    
    SemanticVersion: string | undefined;
    
    SourceCodeArchiveUrl?: string;
    
    SourceCodeUrl?: string;
    
    TemplateBody?: string;
    
    TemplateUrl?: string;
}
export declare namespace CreateApplicationVersionRequest {
    
    const filterSensitiveLog: (obj: CreateApplicationVersionRequest) => any;
}
export interface CreateApplicationVersionResponse {
    
    ApplicationId?: string;
    
    CreationTime?: string;
    
    ParameterDefinitions?: ParameterDefinition[];
    
    RequiredCapabilities?: (Capability | string)[];
    
    ResourcesSupported?: boolean;
    
    SemanticVersion?: string;
    
    SourceCodeArchiveUrl?: string;
    
    SourceCodeUrl?: string;
    
    TemplateUrl?: string;
}
export declare namespace CreateApplicationVersionResponse {
    
    const filterSensitiveLog: (obj: CreateApplicationVersionResponse) => any;
}

export interface RollbackConfiguration {
    
    MonitoringTimeInMinutes?: number;
    
    RollbackTriggers?: RollbackTrigger[];
}
export declare namespace RollbackConfiguration {
    
    const filterSensitiveLog: (obj: RollbackConfiguration) => any;
}
export interface CreateCloudFormationChangeSetRequest {
    
    ApplicationId: string | undefined;
    
    Capabilities?: string[];
    
    ChangeSetName?: string;
    
    ClientToken?: string;
    
    Description?: string;
    
    NotificationArns?: string[];
    
    ParameterOverrides?: ParameterValue[];
    
    ResourceTypes?: string[];
    
    RollbackConfiguration?: RollbackConfiguration;
    
    SemanticVersion?: string;
    
    StackName: string | undefined;
    
    Tags?: Tag[];
    
    TemplateId?: string;
}
export declare namespace CreateCloudFormationChangeSetRequest {
    
    const filterSensitiveLog: (obj: CreateCloudFormationChangeSetRequest) => any;
}
export interface CreateCloudFormationChangeSetResponse {
    
    ApplicationId?: string;
    
    ChangeSetId?: string;
    
    SemanticVersion?: string;
    
    StackId?: string;
}
export declare namespace CreateCloudFormationChangeSetResponse {
    
    const filterSensitiveLog: (obj: CreateCloudFormationChangeSetResponse) => any;
}
export interface CreateCloudFormationTemplateRequest {
    
    ApplicationId: string | undefined;
    
    SemanticVersion?: string;
}
export declare namespace CreateCloudFormationTemplateRequest {
    
    const filterSensitiveLog: (obj: CreateCloudFormationTemplateRequest) => any;
}
export declare enum Status {
    ACTIVE = "ACTIVE",
    EXPIRED = "EXPIRED",
    PREPARING = "PREPARING"
}
export interface CreateCloudFormationTemplateResponse {
    
    ApplicationId?: string;
    
    CreationTime?: string;
    
    ExpirationTime?: string;
    
    SemanticVersion?: string;
    
    Status?: Status | string;
    
    TemplateId?: string;
    
    TemplateUrl?: string;
}
export declare namespace CreateCloudFormationTemplateResponse {
    
    const filterSensitiveLog: (obj: CreateCloudFormationTemplateResponse) => any;
}

export declare class NotFoundException extends __BaseException {
    readonly name: "NotFoundException";
    readonly $fault: "client";
    
    ErrorCode?: string;
    
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
export interface DeleteApplicationRequest {
    
    ApplicationId: string | undefined;
}
export declare namespace DeleteApplicationRequest {
    
    const filterSensitiveLog: (obj: DeleteApplicationRequest) => any;
}
export interface GetApplicationRequest {
    
    ApplicationId: string | undefined;
    
    SemanticVersion?: string;
}
export declare namespace GetApplicationRequest {
    
    const filterSensitiveLog: (obj: GetApplicationRequest) => any;
}
export interface GetApplicationResponse {
    
    ApplicationId?: string;
    
    Author?: string;
    
    CreationTime?: string;
    
    Description?: string;
    
    HomePageUrl?: string;
    
    IsVerifiedAuthor?: boolean;
    
    Labels?: string[];
    
    LicenseUrl?: string;
    
    Name?: string;
    
    ReadmeUrl?: string;
    
    SpdxLicenseId?: string;
    
    VerifiedAuthorUrl?: string;
    
    Version?: Version;
}
export declare namespace GetApplicationResponse {
    
    const filterSensitiveLog: (obj: GetApplicationResponse) => any;
}
export interface GetApplicationPolicyRequest {
    
    ApplicationId: string | undefined;
}
export declare namespace GetApplicationPolicyRequest {
    
    const filterSensitiveLog: (obj: GetApplicationPolicyRequest) => any;
}
export interface GetApplicationPolicyResponse {
    
    Statements?: ApplicationPolicyStatement[];
}
export declare namespace GetApplicationPolicyResponse {
    
    const filterSensitiveLog: (obj: GetApplicationPolicyResponse) => any;
}
export interface GetCloudFormationTemplateRequest {
    
    ApplicationId: string | undefined;
    
    TemplateId: string | undefined;
}
export declare namespace GetCloudFormationTemplateRequest {
    
    const filterSensitiveLog: (obj: GetCloudFormationTemplateRequest) => any;
}
export interface GetCloudFormationTemplateResponse {
    
    ApplicationId?: string;
    
    CreationTime?: string;
    
    ExpirationTime?: string;
    
    SemanticVersion?: string;
    
    Status?: Status | string;
    
    TemplateId?: string;
    
    TemplateUrl?: string;
}
export declare namespace GetCloudFormationTemplateResponse {
    
    const filterSensitiveLog: (obj: GetCloudFormationTemplateResponse) => any;
}
export interface ListApplicationDependenciesRequest {
    
    ApplicationId: string | undefined;
    
    MaxItems?: number;
    
    NextToken?: string;
    
    SemanticVersion?: string;
}
export declare namespace ListApplicationDependenciesRequest {
    
    const filterSensitiveLog: (obj: ListApplicationDependenciesRequest) => any;
}
export interface ListApplicationDependenciesResponse {
    
    Dependencies?: ApplicationDependencySummary[];
    
    NextToken?: string;
}
export declare namespace ListApplicationDependenciesResponse {
    
    const filterSensitiveLog: (obj: ListApplicationDependenciesResponse) => any;
}
export interface ListApplicationsRequest {
    
    MaxItems?: number;
    
    NextToken?: string;
}
export declare namespace ListApplicationsRequest {
    
    const filterSensitiveLog: (obj: ListApplicationsRequest) => any;
}
export interface ListApplicationsResponse {
    
    Applications?: ApplicationSummary[];
    
    NextToken?: string;
}
export declare namespace ListApplicationsResponse {
    
    const filterSensitiveLog: (obj: ListApplicationsResponse) => any;
}
export interface ListApplicationVersionsRequest {
    
    ApplicationId: string | undefined;
    
    MaxItems?: number;
    
    NextToken?: string;
}
export declare namespace ListApplicationVersionsRequest {
    
    const filterSensitiveLog: (obj: ListApplicationVersionsRequest) => any;
}
export interface ListApplicationVersionsResponse {
    
    NextToken?: string;
    
    Versions?: VersionSummary[];
}
export declare namespace ListApplicationVersionsResponse {
    
    const filterSensitiveLog: (obj: ListApplicationVersionsResponse) => any;
}
export interface PutApplicationPolicyRequest {
    
    ApplicationId: string | undefined;
    
    Statements: ApplicationPolicyStatement[] | undefined;
}
export declare namespace PutApplicationPolicyRequest {
    
    const filterSensitiveLog: (obj: PutApplicationPolicyRequest) => any;
}
export interface PutApplicationPolicyResponse {
    
    Statements?: ApplicationPolicyStatement[];
}
export declare namespace PutApplicationPolicyResponse {
    
    const filterSensitiveLog: (obj: PutApplicationPolicyResponse) => any;
}
export interface UnshareApplicationRequest {
    
    ApplicationId: string | undefined;
    
    OrganizationId: string | undefined;
}
export declare namespace UnshareApplicationRequest {
    
    const filterSensitiveLog: (obj: UnshareApplicationRequest) => any;
}
export interface UpdateApplicationRequest {
    
    ApplicationId: string | undefined;
    
    Author?: string;
    
    Description?: string;
    
    HomePageUrl?: string;
    
    Labels?: string[];
    
    ReadmeBody?: string;
    
    ReadmeUrl?: string;
}
export declare namespace UpdateApplicationRequest {
    
    const filterSensitiveLog: (obj: UpdateApplicationRequest) => any;
}
export interface UpdateApplicationResponse {
    
    ApplicationId?: string;
    
    Author?: string;
    
    CreationTime?: string;
    
    Description?: string;
    
    HomePageUrl?: string;
    
    IsVerifiedAuthor?: boolean;
    
    Labels?: string[];
    
    LicenseUrl?: string;
    
    Name?: string;
    
    ReadmeUrl?: string;
    
    SpdxLicenseId?: string;
    
    VerifiedAuthorUrl?: string;
    
    Version?: Version;
}
export declare namespace UpdateApplicationResponse {
    
    const filterSensitiveLog: (obj: UpdateApplicationResponse) => any;
}
